@@ -3,7 +3,7 @@ package Import::Export;
 use Carp;
 use namespace::clean ();
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 our %EX;
 
@@ -27,9 +27,9 @@ sub import {
 	my @exported = export($pkg, $caller, @export);
 	
 	'namespace::clean'->import(
-			-cleanee => $caller,
-			@exported,
-	) if $options->{clean}; # stolen from https://metacpan.org/source/TOBYINK/PerlX-Define-0.101/lib/PerlX/Define.pm#L51 :)
+		-cleanee => $caller,
+		@exported,
+	) if $options->{clean}; 
 }
 
 sub export {
@@ -71,7 +71,7 @@ Import::Export - Exporting
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
